@@ -142,9 +142,9 @@ class MultiprocessDomparserResult():
         index = -1
         for output_html in output_htmls:
             index = index+1
-            soup = BeautifulSoup(output_html[0])
+            soup = BeautifulSoup(output_html[0], features="html.parser")
             body = soup.find('body')
-            body_contents = str(body.findChildren(recursive=False)[0])
+            body_contents = str(body.find_all(recursive=False)[0])
             wrapped_result = f"""
             <li>
                 <div>
